==> httpcomponents-core-5.2.5-src.tar.gz: httpcore5/src/test/java/org/apache/hc/core5/util/TestDeadlineTimeoutException.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */

package org.apache.hc.core5.util;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class TestDeadlineTimeoutException {

    @Test
    public void testMessage() {
        final Deadline deadline = Deadline.fromUnixMilliseconds(1000).freeze();
        Assertions.assertTrue(deadline.isExpired(), deadline.toString());
        final String format = deadline.formatTarget();
        final TimeValue diff = TimeValue.ofMilliseconds(deadline.remaining());
        Assertions.assertEquals("Deadline: " + format + ", " + diff + " overdue",
                DeadlineTimeoutException.from(deadline).getMessage());
    }

    @Test
    public void testInfiniteDeadlineMessage() {
        final Deadline deadline = Deadline.calculate(Timeout.ZERO_MILLISECONDS);
        Assertions.assertEquals("No deadline (infinite)",
                DeadlineTimeoutException.from(deadline).getMessage());
    }

}

==> httpcomponents-core-5.3.6-src.tar.gz: httpcore5/src/test/java/org/apache/hc/core5/util/TestDeadlineTimeoutException.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */

package org.apache.hc.core5.util;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

class TestDeadlineTimeoutException {

    @Test
    void testMessage() {
        final Deadline deadline = Deadline.fromUnixMilliseconds(1000).freeze();
        Assertions.assertTrue(deadline.isExpired(), deadline.toString());
        final String format = deadline.formatTarget();
        final TimeValue diff = TimeValue.ofMilliseconds(deadline.remaining());
        Assertions.assertEquals("Deadline: " + format + ", " + diff + " overdue",
                DeadlineTimeoutException.from(deadline).getMessage());
    }

    @Test
    void testInfiniteDeadlineMessage() {
        final Deadline deadline = Deadline.calculate(Timeout.ZERO_MILLISECONDS);
        Assertions.assertEquals("No deadline (infinite)",
                DeadlineTimeoutException.from(deadline).getMessage());
    }

}
